@@ -20,7 +20,6 @@ if TYPE_CHECKING:
     from typing import TypedDict
     from ...interpreterbase import TYPE_var, TYPE_kwargs
     from .. import ModuleState
-    from .feature import FeatureKwArgs
 
     class TestKwArgs(TypedDict):
         compiler: Optional[Compiler]
@@ -109,6 +108,7 @@ class TargetsObject(ModuleObject):
 
 class Module(NewExtensionModule):
     INFO = ModuleInfo('features', '0.1.0')
+
     def __init__(self) -> None:
         super().__init__()
         self.methods.update({
@@ -142,7 +142,8 @@ class Module(NewExtensionModule):
         self._cache_dict(state)[key] = val
 
     @typed_pos_args('features.test', varargs=FeatureObject, min_varargs=1)
-    @typed_kwargs('features.test',
+    @typed_kwargs(
+        'features.test',
         KwargInfo('compiler', (NoneType, Compiler)),
         KwargInfo('anyfet', bool, default = False),
         KwargInfo('cached', bool, default = True),
@@ -255,7 +256,7 @@ class Module(NewExtensionModule):
         features_any = set()
         for fet in all_features:
             _, test_any_result = self.cached_test(
-                state, features={fet,},
+                state, features={fet, },
                 compiler=compiler,
                 cached=cached,
                 anyfet=False,
@@ -293,7 +294,7 @@ class Module(NewExtensionModule):
             # Set the highest interested feature
             prevalent_features = sorted(features)[-1:]
 
-        prevalent_names =  [fet.name for fet in prevalent_features]
+        prevalent_names = [fet.name for fet in prevalent_features]
         # prepare the result dict
         test_result: 'TestResultKwArgs' = {
             'target_name': '__'.join(prevalent_names),
@@ -307,6 +308,7 @@ class Module(NewExtensionModule):
             'is_disabled': False,
             'fail_reason': '',
         }
+
         def fail_result(fail_reason: str, is_disabled: bool = False
                         ) -> 'TestResultKwArgs':
             test_result.update({
@@ -337,7 +339,7 @@ class Module(NewExtensionModule):
         predecessor_features = implied_features.difference(_caller)
         for fet in sorted(predecessor_features):
             _, pred_result = self.cached_test(
-                state, features={fet,},
+                state, features={fet, },
                 compiler=compiler,
                 cached=cached,
                 anyfet=False,
@@ -371,15 +373,12 @@ class Module(NewExtensionModule):
                 values: List[ConflictAttr] = getattr(fet, attr)
                 accumulate_values = test_result[attr]  # type: ignore
                 for conflict in values:
-                    if not conflict.match:
-                        accumulate_values.append(conflict.val)
-                        continue
                     conflict_vals: List[str] = []
                     # select the acc items based on the match
                     new_acc: List[str] = []
                     for acc in accumulate_values:
                         # not affected by the match so we keep it
-                        if not conflict.match.match(acc):
+                        if not (conflict.match and conflict.match.match(acc)):
                             new_acc.append(acc)
                             continue
                         # no filter so we totaly escape it
@@ -396,7 +395,7 @@ class Module(NewExtensionModule):
                             continue
                         conflict_vals.append(conflict.mjoin.join(filter_val))
                     new_acc.append(conflict.val + conflict.mjoin.join(conflict_vals))
-                    test_result[attr] = new_acc  # type: ignore
+                    accumulate_values = test_result[attr] = new_acc  # type: ignore
 
         test_args = compiler.has_multi_arguments
         args = test_result['args']
@@ -434,7 +433,8 @@ class Module(NewExtensionModule):
         build.GeneratedList, build.StructuredSources, build.ExtractedObjects,
         build.BuildTarget
     ))
-    @typed_kwargs('features.multi_targets',
+    @typed_kwargs(
+        'features.multi_targets',
         KwargInfo(
             'dispatch', (
                 ContainerTypeInfo(list, (FeatureObject, list)),
@@ -454,8 +454,8 @@ class Module(NewExtensionModule):
         allow_unknown=True
     )
     def multi_targets_method(self, state: 'ModuleState',
-                            args: Tuple[str], kwargs: 'TYPE_kwargs'
-                            ) -> TargetsObject:
+                             args: Tuple[str], kwargs: 'TYPE_kwargs'
+                             ) -> TargetsObject:
         config_name = args[0]
         sources = args[1]  # type: ignore
         dispatch: List[Union[FeatureObject, List[FeatureObject]]] = (
@@ -470,7 +470,7 @@ class Module(NewExtensionModule):
         if not compiler:
             compiler = get_compiler(state)
 
-        baseline_features : Set[FeatureObject] = set()
+        baseline_features: Set[FeatureObject] = set()
         has_baseline = baseline is not None
         if has_baseline:
             baseline_features = FeatureObject.get_implicit_combine_multi(baseline)
@@ -491,7 +491,7 @@ class Module(NewExtensionModule):
         ]] = []
         for d in dispatch:
             if isinstance(d, FeatureObject):
-                target = {d,}
+                target = {d, }
                 is_base_part = d in baseline_features
             else:
                 target = set(d)
@@ -650,7 +650,7 @@ class Module(NewExtensionModule):
                 c_detect = '1'
             dispatch_calls.append(
                 f'{prefix}_MTARGETS_EXPAND('
-                    f'EXEC_CB({c_detect}, {test["target_name"]}, __VA_ARGS__)'
+                f'EXEC_CB({c_detect}, {test["target_name"]}, __VA_ARGS__)'
                 ')'
             )
 
@@ -686,7 +686,8 @@ class Module(NewExtensionModule):
         return config_path
 
     @typed_pos_args('features.sort', varargs=FeatureObject, min_varargs=1)
-    @typed_kwargs('features.sort',
+    @typed_kwargs(
+        'features.sort',
         KwargInfo('reverse', bool, default = False),
     )
     def sort_method(self, state: 'ModuleState',
